NuRadioReco.modules.io package
==============================

Subpackages
-----------

.. toctree::

    NuRadioReco.modules.io.coreas
    NuRadioReco.modules.io.noise
    NuRadioReco.modules.io.snowshovel

Submodules
----------

NuRadioReco.modules.io.ARIANNAio module
---------------------------------------

.. automodule:: NuRadioReco.modules.io.ARIANNAio
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco.modules.io.eventReader module
-----------------------------------------

.. automodule:: NuRadioReco.modules.io.eventReader
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco.modules.io.eventWriter module
-----------------------------------------

.. automodule:: NuRadioReco.modules.io.eventWriter
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: NuRadioReco.modules.io
    :members:
    :undoc-members:
    :show-inheritance:
